@@ -20,7 +20,6 @@ def get_credentials():
     import json
     from google.oauth2 import service_account
     from pydatafabric.vault_utils import get_secrets
-
     key = get_secrets(CREDENTIALS_SECRET_MOUNT_POINT, CREDENTIALS_SECRET_PATH)["config"]
     json_acct_info = json.loads(key)
     credentials = service_account.Credentials.from_service_account_info(json_acct_info)
@@ -354,7 +353,7 @@ def _bq_table_to_df(
     from pydatafabric.vault_utils import get_secrets
 
     if not spark_session:
-        spark_session = get_spark()
+        spark_session = get_spark(key_mount=CREDENTIALS_SECRET_MOUNT_POINT, key_path=CREDENTIALS_SECRET_PATH)
     spark_session.conf.set("spark.sql.execution.arrow.pyspark.enabled", "false")
     key = get_secrets(CREDENTIALS_SECRET_MOUNT_POINT, CREDENTIALS_SECRET_PATH)["config"]
     df = (
@@ -549,7 +548,7 @@ def parquet_to_bq_table(
 ):
     try:
         if not spark_session:
-            spark_session = get_spark()
+            spark_session = get_spark(key_mount=CREDENTIALS_SECRET_MOUNT_POINT, key_path=CREDENTIALS_SECRET_PATH)
 
         df = spark_session.read.format("parquet").load(parquet_dir)
         _df_to_bq_table(
@@ -579,7 +578,7 @@ def pandas_to_bq_table(
 ):
     try:
         if not spark_session:
-            spark_session = get_spark()
+            spark_session = get_spark(key_mount=CREDENTIALS_SECRET_MOUNT_POINT, key_path=CREDENTIALS_SECRET_PATH)
 
         spark_df = spark_session.createDataFrame(pd_df)
         _df_to_bq_table(
