@@ -51,7 +51,7 @@ def get_pkl_from_hdfs(pkl_path):
     return pkl_object
 
 
-def get_spark(scale=0, queue=None, extra_jars=None):
+def get_spark(mount="datafabric", path="gcp/emart-datafabric/datafabric", scale=0, queue=None, extra_jars=None):
     import os
     import uuid
     import tempfile
@@ -64,7 +64,7 @@ def get_spark(scale=0, queue=None, extra_jars=None):
     tmp_uuid = str(uuid.uuid4())
     app_name = f"emart-{os.environ.get('USER', 'default')}-{tmp_uuid}"
 
-    key = get_secrets("datafabric", "gcp/emart-datafabric/datafabric")["config"]
+    key = get_secrets(mount, path)["config"]
     key_file_name = tempfile.mkstemp()[1]
     with open(key_file_name, "wb") as key_file:
         key_file.write(key.encode())
